@@ -81,13 +81,13 @@ test_that('NA, Inf, NaNs in input return NA in output', {
   P <- data.frame(a = c(1, NA), b = c(0, 0.5), c = c(0, 0.2))
   tric <- Tricolore(P, 'a', 'b', 'c', breaks = Inf)
   expect_equal(tric$rgb, c('#F0C500', NA))
-  expect_equal(class(tric$key), c('gg', 'ggplot'))
+  expect_true(all(c('gg', 'ggplot') %in% class(tric$key)))
   P <- data.frame(a = c(1, Inf), b = c(0, 0.5), c = c(0, 0.2))
   tric <- Tricolore(P, 'a', 'b', 'c', breaks = Inf)
   expect_equal(tric$rgb, c('#F0C500', NA))
-  expect_equal(class(tric$key), c('gg', 'ggplot'))
+  expect_true(all(c('gg', 'ggplot') %in% class(tric$key)))
   P <- data.frame(a = c(1, NaN), b = c(0, 0.5), c = c(0, 0.2))
   tric <- Tricolore(P, 'a', 'b', 'c', breaks = Inf)
   expect_equal(tric$rgb, c('#F0C500', NA))
-  expect_equal(class(tric$key), c('gg', 'ggplot'))
+  expect_true(all(c('gg', 'ggplot') %in% class(tric$key)))
 })
